Skip to contents

This function will browse available BSgenomes, indicating which one should be installed for the specified organism and genome assembly version. If you cannot specify both organism and genome, the function can return a list of available genomes for a specified species.

Usage

find_BS_genome(organism, genome, masked = FALSE)

Arguments

organism

the name of the organism for which to install the reference genome. This can be the scientific name or a common name. For example Homo Sapiens, H. sapiens, or human

genome

The reference genome assembly version. Ex. hg18, mm10, rn6.

masked

Logical value. Whether to search for the 'masked' BSgenome. Default is FALSE.

Value

a BSgenome package name or a dataframe of possibilities

Examples

# Find the reference genome for Mouse, mm10 assembly:
mouse_mm10 <- find_BS_genome("mouse", "mm10")
#> 'getOption("repos")' replaces Bioconductor standard repositories, see
#> 'help("repositories", package = "BiocManager")' for details.
#> Replacement repositories:
#>     CRAN: https://cran.rstudio.com
#> Selected reference genome: BSgenome.Mmusculus.UCSC.mm10
#> Reference genome is already installed.
#> Once installed, supply 'BSgenome.Mmusculus.UCSC.mm10' as the BS_genome parameter.